#
# spec file for package python-django-auth-ldap
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-django-auth-ldap
Version:        1.2.6
Release:        3.1
Url:            http://bitbucket.org/psagers/django-auth-ldap/
Summary:        Django LDAP authentication backend
License:        BSD-2-Clause
Group:          Development/Languages/Python
Source:         https://pypi.python.org/packages/source/d/django-auth-ldap/django-auth-ldap-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  python-rpm-macros
Requires:       python-django
Requires:       python-ldap
BuildArch:      noarch

%python_subpackages

%description
This is a Django authentication backend that authenticates against an LDAP service.
Configuration can be as simple as a single distinguished name template, but there
are many rich configuration options for working with users, groups, and permissions.

%prep
%setup -q -n django-auth-ldap-%{version}

%build
%python_build

%install
%python_install

%files %{python_files}
%defattr(-,root,root,-)
%doc CHANGES LICENSE README
%{python_sitelib}/*

%changelog
* Tue Jan 23 2018 mimi.vx@gmail.com
- convert to singlespec
* Thu Apr 23 2015 mcihar@suse.cz
- Update to 1.2.6:
  - Performance improvements to group mirroring (from
    `Denver Janke <https://bitbucket.org/denverjanke>`_).
  - Add :data:`django_auth_ldap.backend.ldap_error` signal for custom handling of
    :exc:`~ldap.LDAPError` exceptions.
  - Add :data:`django_auth_ldap.backend.LDAPBackend.default_settings` for
    per-subclass default settings.
  - Fix interaction between :setting:`AUTH_LDAP_AUTHORIZE_ALL_USERS` and
    :setting:`AUTH_LDAP_USER_SEARCH`.
  - Add support for nisNetgroup groups (thanks to Christopher Bartz).
  - Fix `#50`_: Improved escaping for filter strings.
  - Accept (and ignore) arbitrary keyword arguments to
    :meth:`~django_auth_ldap.backend.LDAPBackend.authenticate`.
* Wed Oct  8 2014 mcihar@suse.cz
- Update to 1.2.2:
  - Include test harness in source distribution. Some package maintainers find
    this helpful.
  - More verbose log messages for authentication failures.
* Fri Apr 25 2014 mcihar@suse.cz
- Update to 1.2.0:
  * django-auth-ldap now provides experimental Python 3 support. Python 2.5
    was dropped.
- Use pypi URL as source
* Fri Feb 14 2014 mcihar@suse.cz
- Update to 1.1.8:
  * Fix #43: Update django_auth_ldap.config.LDAPSearchUnion to work for
    group searches in addition to user searches.
  * Tox no longer supports Python 2.5, so our tests now run on 2.6 and 2.7 only.
  * Bug fix: AUTH_LDAP_GLOBAL_OPTIONS could be ignored in some cases
    (such as django_auth_ldap.backend.LDAPBackend.populate_user.
  * Fix #41: Support POSIX group permissions with no gidNumber attribute.
  * Support multiple group DNs for *_FLAGS_BY_GROUP.
* Thu Nov 21 2013 mcihar@suse.cz
- add missing dependency on python-ldap
* Wed May 15 2013 tchatzimichos@suse.com
- Update to 1.1.4:
  * Add support for Django 1.5's custom user models.
  * Add %%doc files
* Mon Jan  7 2013 alexandre@exatati.com.br
- Update to 1.1.3:
  * Fix #33: Reject empty passwords by default.
    Unless AUTH_LDAP_PERMIT_EMPTY_PASSWORD is set to True,
    LDAPBackend.authenticate() will immediately return None if the password is
    empty. This is technically backwards-incompatible, but it's a more secure
    default for those LDAP servers that are configured such that binds without
    passwords always succeed.
  * Fix #39: Add support for pickling LDAP-authenticated users.
* Thu Aug 30 2012 alexandre@exatati.com.br
- Update to 1.1.2:
  - Sorry, no changelog.
* Mon Jul  9 2012 alexandre@exatati.com.br
- Update to 1.1.1:
  - Sorry, no changelog.
* Mon May  7 2012 alexandre@exatati.com.br
- Update to 1.1:
  - Sorry, no changelog.
* Mon Mar 26 2012 alexandre@exatati.com.br
- Update to 1.0.19:
  - Sorry, no changelog.
* Thu Mar 15 2012 alexandre@exatati.com.br
- Update to 1.0.18:
  - Sorry, no changelog.
* Fri Mar  9 2012 alexandre@exatati.com.br
- Update to 1.0.17:
  - Sorry, no changelog atm.
* Sun Feb  5 2012 alexandre@exatati.com.br
- Update to 1.0.15:
  - Sorry, no changelog atm.
* Thu Dec 29 2011 alexandre@exatati.com.br
- Update to 1.0.14:
  - Sorry, no changelog atm.
* Thu Dec 15 2011 alexandre@exatati.com.br
- Update to 1.0.13:
  - Sorry, no changelog atm.
* Fri Sep 30 2011 alexandre@exatati.com.br
- Update to 1.0.12:
  - Sorry, no changelog.
* Mon Aug 29 2011 alexandre@exatati.com.br
- Update to 1.0.11:
  - Sorry, no changelog.
* Fri Jun 24 2011 alexandre@exatati.com.br
- Update to 1.0.10:
  - Sorry, no changelog.
- Regenerate spec file with py2pack.
* Tue Mar 29 2011 alexandre@exatati.com.br
- Update to 1.0.9.
* Sun Mar 13 2011 alexandre@exatati.com.br
- Update to 1.0.8;
- Regenerated spec file with py2pack.
* Sat Dec  4 2010 alexandre@exatati.com.br
- Update to 1.0.7.
* Fri Jul 30 2010 alexandre@exatati.com.br
- Update to 1.0.6.
* Tue Jun 22 2010 alexandre@exatati.com.br
- Update to 1.0.5.
* Mon Jun  7 2010 alexandre@exatati.com.br
- Update to 1.0.4.
* Sat Apr  3 2010 alexandre@exatati.com.br
- Update to 1.0.3;
- Spec file cleaned with spec-cleaner.
* Sun Mar 28 2010 alexandre@exatati.com.br
- Update to 1.0.2.
* Sun Mar 14 2010 alexandre@exatati.com.br
- Update to 1.0.1.
* Sat Jan  2 2010 alexandre@exatati.com.br
- Update to 1.0.
* Mon Nov  2 2009 alexandre@exatati.com.br
- Update to 1.0b7.
* Mon Oct 26 2009 alexandre@exatati.com.br
- Update to 1.0b6.
* Mon Oct 26 2009 alexandre@exatati.com.br
- Update to 1.0b5.
* Tue Oct 20 2009 alexandre@exatati.com.br
- Update to 1.0b4.
* Thu Oct 15 2009 alexandre@exatati.com.br
- Update to 1.0b3.
* Mon Sep 28 2009 alexandre@exatati.com.br
- Update to 1.0b2.
* Fri Sep 25 2009 alexandre@exatati.com.br
- Initial package (1.0b1).
